==> 1.0.2.tar.gz: doc/UserApi.md <==
# forestvpn_api.api.UserApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getFeatures**](UserApi.md#getFeatures) | **GET** /user/features/ | Get active user features
[**getPreference**](UserApi.md#getPreference) | **GET** /user/preference/ | Get user preference
[**getPremium**](UserApi.md#getPremium) | **GET** /user/premium/ | Get premium status details
[**updatePreference**](UserApi.md#updatePreference) | **PATCH** /user/preference/ | Update user preference


# **getFeatures**
> List<Feature> getFeatures()

Get active user features

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UserApi();

try { 
    var result = api_instance.getFeatures();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getFeatures: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<Feature>**](Feature.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPreference**
> Preference getPreference()

Get user preference

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UserApi();

try { 
    var result = api_instance.getPreference();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getPreference: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Preference**](Preference.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPremium**
> Premium getPremium()

Get premium status details

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UserApi();

try { 
    var result = api_instance.getPremium();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getPremium: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Premium**](Premium.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePreference**
> Preference updatePreference(request)

Update user preference

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UserApi();
var request = new PreferenceUpdateRequest(); // PreferenceUpdateRequest | 

try { 
    var result = api_instance.updatePreference(request);
    print(result);
} catch (e) {
    print("Exception when calling UserApi->updatePreference: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**PreferenceUpdateRequest**](PreferenceUpdateRequest.md)|  | 

### Return type

[**Preference**](Preference.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.0.3.tar.gz: doc/UserApi.md <==
# forestvpn_api.api.UserApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getFeatures**](UserApi.md#getFeatures) | **GET** /user/features/ | Get active user features
[**getPreference**](UserApi.md#getPreference) | **GET** /user/preference/ | Get user preference
[**getPremium**](UserApi.md#getPremium) | **GET** /user/premium/ | Get premium status details
[**updatePreference**](UserApi.md#updatePreference) | **PATCH** /user/preference/ | Update user preference


# **getFeatures**
> List<Feature> getFeatures()

Get active user features

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();

try { 
    var result = api_instance.getFeatures();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getFeatures: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<Feature>**](Feature.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPreference**
> Preference getPreference()

Get user preference

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();

try { 
    var result = api_instance.getPreference();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getPreference: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Preference**](Preference.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getPremium**
> Premium getPremium()

Get premium status details

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();

try { 
    var result = api_instance.getPremium();
    print(result);
} catch (e) {
    print("Exception when calling UserApi->getPremium: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Premium**](Premium.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePreference**
> Preference updatePreference(request)

Update user preference

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UserApi();
var request = PreferenceUpdateRequest(); // PreferenceUpdateRequest | 

try { 
    var result = api_instance.updatePreference(request);
    print(result);
} catch (e) {
    print("Exception when calling UserApi->updatePreference: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**PreferenceUpdateRequest**](PreferenceUpdateRequest.md)|  | 

### Return type

[**Preference**](Preference.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
